==> react-atom-tooltip-1.8.0.tgz: package/lib/hoc/withIntersectionObserver.js <==
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";

/* global IntersectionObserver */
import React, { Component } from 'react';

if (typeof window !== 'undefined' && window.document) {
  require('intersection-observer');
}

export default (function (BaseComponent) {
  var _class, _temp;

  var displayName = BaseComponent.displayName;
  return _temp = _class =
  /*#__PURE__*/
  function (_Component) {
    _inheritsLoose(WithIntersectionObserver, _Component);

    function WithIntersectionObserver() {
      var _this;

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      _this = _Component.call.apply(_Component, [this].concat(args)) || this;
      _this.state = {
        isIntersecting: true
      };

      _this.handleChange = function (_ref) {
        var isIntersecting = _ref[0].isIntersecting;

        _this.setState({
          isIntersecting: isIntersecting
        });
      };

      _this.innerRef = function (elem) {
        _this.refTarget = elem;
      };

      return _this;
    }

    var _proto = WithIntersectionObserver.prototype;

    _proto.componentDidMount = function componentDidMount() {
      var target = this.refTarget; // check we support IntersectionObserver

      if (!('IntersectionObserver' in window)) {
        this.setState({
          isIntersecting: true
        });
        return;
      }

      new IntersectionObserver(this.handleChange).observe(target);
    };

    _proto.render = function render() {
      var isVisible = this.state.isIntersecting;
      return React.createElement(BaseComponent, Object.assign({}, this.props, {
        isVisible: isVisible,
        innerRef: this.innerRef
      }));
    };

    return WithIntersectionObserver;
  }(Component), _class.displayName = "withIntersectionObserver(" + displayName + ")", _class.contextTypes = BaseComponent.contextTypes, _temp;
});

==> react-atom-tooltip-1.9.0.tgz: package/lib/hoc/withIntersectionObserver.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";

/* global IntersectionObserver */
import React, { Component } from 'react';

if (typeof window !== 'undefined' && window.document) {
  require('intersection-observer');
}

export default (function (BaseComponent) {
  var _class, _temp;

  var displayName = BaseComponent.displayName;
  return _temp = _class =
  /*#__PURE__*/
  function (_Component) {
    _inheritsLoose(WithIntersectionObserver, _Component);

    function WithIntersectionObserver() {
      var _this;

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      _this = _Component.call.apply(_Component, [this].concat(args)) || this;
      _this.state = {
        isIntersecting: true
      };

      _this.handleChange = function (_ref) {
        var _ref2 = _slicedToArray(_ref, 1),
            isIntersecting = _ref2[0].isIntersecting;

        _this.setState({
          isIntersecting: isIntersecting
        });
      };

      _this.innerRef = function (elem) {
        _this.refTarget = elem;
      };

      return _this;
    }

    var _proto = WithIntersectionObserver.prototype;

    _proto.componentDidMount = function componentDidMount() {
      var target = this.refTarget; // check we support IntersectionObserver

      if (!('IntersectionObserver' in window)) {
        this.setState({
          isIntersecting: true
        });
        return;
      }

      new IntersectionObserver(this.handleChange).observe(target);
    };

    _proto.render = function render() {
      var isVisible = this.state.isIntersecting;
      return React.createElement(BaseComponent, Object.assign({}, this.props, {
        isVisible: isVisible,
        innerRef: this.innerRef
      }));
    };

    return WithIntersectionObserver;
  }(Component), _class.displayName = "withIntersectionObserver(" + displayName + ")", _class.contextTypes = BaseComponent.contextTypes, _temp;
});
